@@ -519,7 +519,7 @@ func (ui *gameui) DrawKeysDescription(title string, actions []string) {
 		ui.DrawColoredTextOnBG(fmt.Sprintf(" %-36s %s", actions[i], actions[i+1]), 0, i/2+1, ColorFg, bg)
 	}
 	lines := 1 + len(actions)/2
-	ui.DrawTextLine(" press esc or space to continue ", lines)
+	ui.DrawTextLine(" press (x) to continue ", lines)
 	ui.Flush()
 
 	ui.WaitForContinue(lines)
@@ -588,7 +588,7 @@ func (ui *gameui) CharacterInfo() {
 		ui.ClearLine(i)
 	}
 	ui.DrawText(desc, 0, 0)
-	escspace := " press esc or space to continue "
+	escspace := " press (x) to continue "
 	if lines+2 >= DungeonHeight {
 		ui.DrawTextLine(escspace, lines+2)
 		ui.SetCell(DungeonWidth, lines+2, '┘', ColorFg, ColorBg)
@@ -692,7 +692,7 @@ func (ui *gameui) DescribePosition(pos position, targ Targeter) {
 	case okStair:
 		if strt == WinStair {
 			desc = ui.AddComma(see, desc)
-			desc += fmt.Sprintf("glowing stairs")
+			desc += fmt.Sprintf("glowing monolith")
 		} else {
 			desc = ui.AddComma(see, desc)
 			desc += fmt.Sprintf("stairs downwards")
@@ -744,9 +744,9 @@ func (ui *gameui) ViewPositionDescription(pos position) {
 		ui.DrawDescription(eq.Desc())
 	} else if strt, ok := g.Stairs[pos]; ok {
 		if strt == WinStair {
-			desc := "These shiny-looking stairs are in fact a magical monolith. It is said they were made some centuries ago by Marevor Helith. They will lead you back to your village."
+			desc := "This magical monolith will teleport you back to your village. It is said such monoliths were made some centuries ago by Marevor Helith. You can use it like stairs."
 			if g.Depth < MaxDepth {
-				desc += " Note that this is not the last floor, so you may want to find a normal stair and continue collecting simellas, if you're courageous enough."
+				desc += " Note that this is not the last floor, so you may want to find a stair and continue collecting simellas, if you're courageous enough."
 			}
 			ui.DrawDescription(desc)
 		} else {
@@ -973,6 +973,7 @@ func (ui *gameui) PositionDrawing(pos position) (r rune, fgColor, bgColor uicolo
 			r = '>'
 			if strt == WinStair {
 				fgColor = ColorFgMagicPlace
+				r = 'Δ'
 			} else {
 				fgColor = ColorFgPlace
 			}
@@ -1272,12 +1273,12 @@ func InRuneSlice(r rune, s []rune) bool {
 
 func (ui *gameui) RunesForKeyAction(k keyAction) string {
 	runes := []rune{}
-	for r, ka := range gameConfig.RuneNormalModeKeys {
+	for r, ka := range GameConfig.RuneNormalModeKeys {
 		if k == ka && !InRuneSlice(r, runes) {
 			runes = append(runes, r)
 		}
 	}
-	for r, ka := range gameConfig.RuneTargetModeKeys {
+	for r, ka := range GameConfig.RuneTargetModeKeys {
 		if k == ka && !InRuneSlice(r, runes) {
 			runes = append(runes, r)
 		}
@@ -1332,7 +1333,7 @@ loop:
 			}
 		}
 		ui.ClearLine(lines)
-		ui.DrawStyledTextLine(" add key (a) up/down (arrows/u/d) reset (R) quit (esc or space) ", lines, FooterLine)
+		ui.DrawStyledTextLine(" add key (a) up/down (arrows/u/d) reset (R) quit (x) ", lines, FooterLine)
 		ui.Flush()
 
 		var action keyConfigAction
@@ -1364,14 +1365,14 @@ loop:
 			CustomKeys = true
 			ka := configurableKeyActions[s]
 			if ka.NormalModeKey() {
-				gameConfig.RuneNormalModeKeys[r] = ka
+				GameConfig.RuneNormalModeKeys[r] = ka
 			} else {
-				delete(gameConfig.RuneNormalModeKeys, r)
+				delete(GameConfig.RuneNormalModeKeys, r)
 			}
 			if ka.TargetingModeKey() {
-				gameConfig.RuneTargetModeKeys[r] = ka
+				GameConfig.RuneTargetModeKeys[r] = ka
 			} else {
-				delete(gameConfig.RuneTargetModeKeys, r)
+				delete(GameConfig.RuneTargetModeKeys, r)
 			}
 			err := g.SaveConfig()
 			if err != nil {
@@ -1439,7 +1440,7 @@ loop:
 			ui.ClearLine(i - n)
 		}
 		ui.ClearLine(lines)
-		s := fmt.Sprintf(" half-page up/down (u/d) quit (esc or space) — (%d/%d) \n", len(g.Log)-to, len(g.Log))
+		s := fmt.Sprintf(" half-page up/down (u/d) quit (x) — (%d/%d) \n", len(g.Log)-to, len(g.Log))
 		ui.DrawStyledTextLine(s, lines, FooterLine)
 		ui.Flush()
 		var quit bool
@@ -1469,7 +1470,7 @@ func (ui *gameui) DrawDescription(desc string) {
 		ui.ClearLine(i)
 	}
 	ui.DrawText(desc, 0, 0)
-	ui.DrawTextLine(" press esc or space to continue ", lines+2)
+	ui.DrawTextLine(" press (x) to continue ", lines+2)
 	ui.Flush()
 	ui.WaitForContinue(lines + 2)
 	ui.DrawDungeonView(NoFlushMode)
@@ -1600,7 +1601,7 @@ func (ui *gameui) SelectProjectile(ev event) error {
 		for i, c := range cs {
 			ui.ConsumableItem(i, i+1, c, ColorFg)
 		}
-		ui.DrawTextLine(" press esc or space to cancel ", len(cs)+1)
+		ui.DrawTextLine(" press (x) to cancel ", len(cs)+1)
 		ui.Flush()
 		index, alt, err := ui.Select(len(cs))
 		if alt {
@@ -1642,7 +1643,7 @@ func (ui *gameui) SelectPotion(ev event) error {
 		for i, c := range cs {
 			ui.ConsumableItem(i, i+1, c, ColorFg)
 		}
-		ui.DrawTextLine(" press esc or space to cancel ", len(cs)+1)
+		ui.DrawTextLine(" press (x) to cancel ", len(cs)+1)
 		ui.Flush()
 		index, alt, err := ui.Select(len(cs))
 		if alt {
@@ -1696,7 +1697,7 @@ func (ui *gameui) SelectRod(ev event) error {
 		for i, r := range rs {
 			ui.RodItem(i, i+1, r, ColorFg)
 		}
-		ui.DrawTextLine(" press esc or space to cancel ", len(rs)+1)
+		ui.DrawTextLine(" press (x) to cancel ", len(rs)+1)
 		ui.Flush()
 		index, alt, err := ui.Select(len(rs))
 		if alt {
@@ -1749,7 +1750,7 @@ func (ui *gameui) SelectAction(actions []keyAction, ev event) (keyAction, error)
 		for i, r := range actions {
 			ui.ActionItem(i, i+1, r, ColorFg)
 		}
-		ui.DrawTextLine(" press esc or space to cancel ", len(actions)+1)
+		ui.DrawTextLine(" press (x) to cancel ", len(actions)+1)
 		ui.Flush()
 		index, alt, err := ui.Select(len(actions))
 		if alt {
@@ -1811,7 +1812,7 @@ func (ui *gameui) SelectConfigure(actions []setting) (setting, error) {
 		for i, r := range actions {
 			ui.ConfItem(i, i+1, r, ColorFg)
 		}
-		ui.DrawTextLine(" press esc or space to cancel ", len(actions)+1)
+		ui.DrawTextLine(" press (x) to cancel ", len(actions)+1)
 		ui.Flush()
 		index, alt, err := ui.Select(len(actions))
 		if alt {
@@ -1839,12 +1840,12 @@ func (ui *gameui) HandleSettingAction() error {
 	case setKeys:
 		ui.ChangeKeys()
 	case invertLOS:
-		gameConfig.DarkLOS = !gameConfig.DarkLOS
+		GameConfig.DarkLOS = !GameConfig.DarkLOS
 		err := g.SaveConfig()
 		if err != nil {
 			g.Print(err.Error())
 		}
-		if gameConfig.DarkLOS {
+		if GameConfig.DarkLOS {
 			ApplyDarkLOS()
 		} else {
 			ApplyLightLOS()
@@ -1880,7 +1881,7 @@ func (ui *gameui) SelectWizardMagic(actions []wizardAction) (wizardAction, error
 		for i, r := range actions {
 			ui.WizardItem(i, i+1, r, ColorFg)
 		}
-		ui.DrawTextLine(" press esc or space to cancel ", len(actions)+1)
+		ui.DrawTextLine(" press (x) to cancel ", len(actions)+1)
 		ui.Flush()
 		index, alt, err := ui.Select(len(actions))
 		if alt {
