@@ -1,8 +1,11 @@
 package main
 
-import "container/heap"
+import (
+	"container/heap"
+	"fmt"
+)
 
-var Version string = "v0.12"
+var Version string = "v0.13"
 
 type game struct {
 	Dungeon             *dungeon
@@ -335,6 +338,15 @@ func (g *game) InitPlayer() {
 		g.Player.Consumables[AccuracyPotion] = 1
 	}
 	r := g.RandomRod()
+	items := r.String()
+	for c, n := range g.Player.Consumables {
+		if n == 1 {
+			items += ", " + c.String()
+		} else {
+			items += fmt.Sprintf(", %d %s", n, c.Plural())
+		}
+	}
+	g.StoryPrintf("Started with %s", items)
 	g.Player.Rods = map[rod]rodProps{r: rodProps{r.MaxCharge() - 1}}
 	g.Player.Statuses = map[status]int{}
 	g.Player.Expire = map[status]int{}
@@ -788,13 +800,13 @@ func (g *game) FrundisInLevel() bool {
 func (g *game) Descend() bool {
 	g.LevelStats()
 	if strt, ok := g.Stairs[g.Player.Pos]; ok && strt == WinStair {
-		g.StoryPrint("You escaped!")
+		g.StoryPrint("Escaped!")
 		g.ExploredLevels = g.Depth
 		g.Depth = -1
 		return true
 	}
 	g.Print("You descend deeper in the dungeon.")
-	g.StoryPrint("You descended deeper in the dungeon.")
+	g.StoryPrint("Descended deeper in the dungeon.")
 	g.Depth++
 	g.DepthPlayerTurn = 0
 	g.Boredom = 0
