@@ -47,7 +47,7 @@ loop:
 		in := ui.PollEvent()
 		r := ui.KeyToRuneKeyAction(in)
 		switch r {
-		case '\x1b', ' ':
+		case '\x1b', ' ', 'x', 'X':
 			break loop
 		}
 		if in.mouse && in.button == -1 {
@@ -221,7 +221,7 @@ func (ui *gameui) PlayerTurnEvent(ev event) (err error, again, quit bool) {
 func (ui *gameui) Scroll(n int) (m int, quit bool) {
 	in := ui.PollEvent()
 	switch in.key {
-	case "Escape", "\x1b", " ":
+	case "Escape", "\x1b", " ", "x", "X":
 		quit = true
 	case "u", "9", "b":
 		n -= 12
@@ -260,16 +260,53 @@ func (ui *gameui) GetPos(i int) (int, int) {
 }
 
 func (ui *gameui) Select(l int) (index int, alternate bool, err error) {
+	if ui.itemHover >= 1 && ui.itemHover <= l {
+		ui.ColorLine(ui.itemHover, ColorYellow)
+		ui.Flush()
+	} else {
+		ui.itemHover = -1
+	}
 	for {
 		in := ui.PollEvent()
 		r := ui.ReadKey(in.key)
 		switch {
-		case in.key == "\x1b" || in.key == "Escape" || in.key == " ":
+		case in.key == "\x1b" || in.key == "Escape" || in.key == " " || in.key == "x" || in.key == "X":
 			return -1, false, errors.New(DoNothing)
 		case in.key == "?":
 			return -1, true, nil
 		case 97 <= r && int(r) < 97+l:
+			if ui.itemHover >= 1 && ui.itemHover <= l {
+				ui.ColorLine(ui.itemHover, ColorFg)
+			}
+			ui.itemHover = int(r-97) + 1
 			return int(r - 97), false, nil
+		case in.key == "2":
+			oih := ui.itemHover
+			ui.itemHover++
+			if ui.itemHover < 1 || ui.itemHover > l {
+				ui.itemHover = 1
+			}
+			if oih > 0 && oih <= l {
+				ui.ColorLine(oih, ColorFg)
+			}
+			ui.ColorLine(ui.itemHover, ColorYellow)
+			ui.Flush()
+		case in.key == "8":
+			oih := ui.itemHover
+			ui.itemHover--
+			if ui.itemHover < 1 {
+				ui.itemHover = l
+			}
+			if oih > 0 && oih <= l {
+				ui.ColorLine(oih, ColorFg)
+			}
+			ui.ColorLine(ui.itemHover, ColorYellow)
+			ui.Flush()
+		case in.key == "." && ui.itemHover >= 1 && ui.itemHover <= l:
+			if ui.itemHover >= 1 && ui.itemHover <= l {
+				ui.ColorLine(ui.itemHover, ColorFg)
+			}
+			return ui.itemHover - 1, false, nil
 		case in.key == "" && in.mouse:
 			y := in.mouseY
 			x := in.mouseX
@@ -278,7 +315,7 @@ func (ui *gameui) Select(l int) (index int, alternate bool, err error) {
 				oih := ui.itemHover
 				if y <= 0 || y > l || x >= DungeonWidth {
 					ui.itemHover = -1
-					if oih != -1 {
+					if oih > 0 {
 						ui.ColorLine(oih, ColorFg)
 						ui.Flush()
 					}
@@ -289,7 +326,7 @@ func (ui *gameui) Select(l int) (index int, alternate bool, err error) {
 				}
 				ui.itemHover = y
 				ui.ColorLine(y, ColorYellow)
-				if oih != -1 {
+				if oih > 0 {
 					ui.ColorLine(oih, ColorFg)
 				}
 				ui.Flush()
@@ -321,7 +358,7 @@ func (ui *gameui) KeyMenuAction(n int) (m int, action keyConfigAction) {
 	switch string(r) {
 	case "a":
 		action = ChangeKeys
-	case "\x1b", " ":
+	case "\x1b", " ", "x", "X":
 		action = QuitKeyConfig
 	case "u":
 		n -= DungeonHeight / 2
@@ -355,7 +392,7 @@ func (ui *gameui) TargetModeEvent(targ Targeter, data *examineData) (err error,
 	again = true
 	in := ui.PollEvent()
 	switch in.key {
-	case "\x1b", "Escape", " ":
+	case "\x1b", "Escape", " ", "x", "X":
 		g.Targeting = InvalidPos
 		notarg = true
 	case "":
@@ -434,7 +471,7 @@ func (ui *gameui) ReadRuneKey() rune {
 	for {
 		in := ui.PollEvent()
 		switch in.key {
-		case "\x1b", "Escape", " ":
+		case "\x1b", "Escape", " ", "x", "X":
 			return 0
 		case "Enter":
 			return '.'
@@ -577,7 +614,7 @@ var CustomKeys bool
 
 func FixedRuneKey(r rune) bool {
 	switch r {
-	case ' ', '?', '=':
+	case ' ', '?', '=', '.', '\x1b', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'x', 'X':
 		return true
 	default:
 		return false
@@ -778,10 +815,10 @@ func (k keyAction) TargetingModeKey() bool {
 	}
 }
 
-var gameConfig config
+var GameConfig config
 
 func ApplyDefaultKeyBindings() {
-	gameConfig.RuneNormalModeKeys = map[rune]keyAction{
+	GameConfig.RuneNormalModeKeys = map[rune]keyAction{
 		'h': KeyW,
 		'j': KeyS,
 		'k': KeyN,
@@ -834,7 +871,7 @@ func ApplyDefaultKeyBindings() {
 		'@': KeyWizardInfo,
 		'=': KeyConfigure,
 	}
-	gameConfig.RuneTargetModeKeys = map[rune]keyAction{
+	GameConfig.RuneTargetModeKeys = map[rune]keyAction{
 		'h':    KeyW,
 		'j':    KeyS,
 		'k':    KeyN,
@@ -877,6 +914,8 @@ func ApplyDefaultKeyBindings() {
 		'e':    KeyExclude,
 		' ':    KeyEscape,
 		'\x1b': KeyEscape,
+		'x':    KeyEscape,
+		'X':    KeyEscape,
 		'?':    KeyHelp,
 	}
 	CustomKeys = false
@@ -891,7 +930,7 @@ func (ui *gameui) HandleKeyAction(rka runeKeyAction) (err error, again bool, qui
 	g := ui.g
 	if rka.r != 0 {
 		var ok bool
-		rka.k, ok = gameConfig.RuneNormalModeKeys[rka.r]
+		rka.k, ok = GameConfig.RuneNormalModeKeys[rka.r]
 		if !ok {
 			switch rka.r {
 			case 's':
@@ -1195,7 +1234,7 @@ func (ui *gameui) CursorKeyAction(targ Targeter, rka runeKeyAction, data *examin
 	again = true
 	if rka.r != 0 {
 		var ok bool
-		rka.k, ok = gameConfig.RuneTargetModeKeys[rka.r]
+		rka.k, ok = GameConfig.RuneTargetModeKeys[rka.r]
 		if !ok {
 			err = fmt.Errorf("Invalid targeting mode key '%c'. Type ? for help.", rka.r)
 			return err, again, quit, notarg
@@ -1546,7 +1585,7 @@ func (ui *gameui) HandleWizardAction() error {
 
 func (ui *gameui) Death() {
 	g := ui.g
-	g.Print("You die... --press esc or space to continue--")
+	g.Print("You die... [(x) to continue]")
 	ui.DrawDungeonView(NormalMode)
 	ui.WaitForContinue(-1)
 	err := g.WriteDump()
@@ -1561,9 +1600,9 @@ func (ui *gameui) Win() {
 		g.PrintfStyled("Error removing save file: %v", logError, err)
 	}
 	if g.Wizard {
-		g.Print("You escape by the magic stairs! **WIZARD** --press esc or space to continue--")
+		g.Print("You escape by the magic portal! **WIZARD** [(x) to continue]")
 	} else {
-		g.Print("You escape by the magic stairs! You win. --press esc or space to continue--")
+		g.Print("You escape by the magic portal! You win. [(x) to continue]")
 	}
 	ui.DrawDungeonView(NormalMode)
 	ui.WaitForContinue(-1)
@@ -1581,7 +1620,7 @@ func (ui *gameui) Dump(err error) {
 
 func (ui *gameui) CriticalHPWarning() {
 	g := ui.g
-	g.PrintStyled("*** CRITICAL HP WARNING *** --press esc or space to continue--", logCritic)
+	g.PrintStyled("*** CRITICAL HP WARNING *** [(x) to continue]", logCritic)
 	ui.DrawDungeonView(NormalMode)
 	ui.WaitForContinue(DungeonHeight)
 	g.Print("Ok. Be careful, then.")
@@ -1595,7 +1634,7 @@ func (ui *gameui) Quit() bool {
 	if quit {
 		err := g.RemoveSaveFile()
 		if err != nil {
-			g.PrintfStyled("Error removing save file: %v ——press any key to quit——", logError, err)
+			g.PrintfStyled("Error removing save file: %v [press any key to quit]", logError, err)
 			ui.DrawDungeonView(NormalMode)
 			ui.PressAnyKey()
 		}
@@ -1667,10 +1706,10 @@ func (ui *gameui) DrawBufferInit() {
 }
 
 func ApplyConfig() {
-	if gameConfig.RuneNormalModeKeys == nil || gameConfig.RuneTargetModeKeys == nil {
+	if GameConfig.RuneNormalModeKeys == nil || GameConfig.RuneTargetModeKeys == nil {
 		ApplyDefaultKeyBindings()
 	}
-	if gameConfig.DarkLOS {
+	if GameConfig.DarkLOS {
 		ApplyDarkLOS()
 	} else {
 		ApplyLightLOS()
